/**
* @file
* @brief 選択レイヤー、選択範囲のみ新しいドキュメントにコピーし、X, Y, WIDTH, HEIGHTを表示するスクリプト
* @author dex
* @date $Date: 2010-03-11 16:13:15 +0900 (木, 11  3月 2010) $
* @version $Revision: 130 $
* @note
* - 動作環境: Photoshop CS3/CS4 Windows版
* - encoding: UTF-8N
* - http://dex.qp.land.to/pukiwiki/
* - License: http://ja.wikipedia.org/wiki/MIT_License
* - Changelog
*   - 2010/03/11	「表示レイヤーを結合してコピー」選択肢を追加
* 						任意の選択範囲に対応。指定しなければレイヤー全体。
* 						レイヤーセットの場合は結合しないと真っ白になるため、結合コピーのみ
*   - 2010/03/03	コピーしたレイヤー名を指定できるように変更。
* 						コピー後の背景レイヤーを非表示に変更し、保存時に楽になるように
*   - 2010/03/02	リリース
*/

/// main
function main()
{
	var saveUnit = preferences.rulerUnits;
	preferences.rulerUnits = Units.PIXELS;

	var activeDoc = activeDocument;	// アクティブドキュメント
	var activeLay = activeDoc.activeLayer; // アクティブレイヤー

	var x1 = parseInt(activeLay.bounds[0]); // 左上座標
	var y1 = parseInt(activeLay.bounds[1]);
	var x2 = parseInt(activeLay.bounds[2]); // 右下座標
	var y2 = parseInt(activeLay.bounds[3]);
	var width = x2 - x1; // 幅
	var height = y2 - y1; // 高さ
	var copy_flag = false; // 結合してコピーするか

	try{
		// 選択範囲がある
		var boundsObj = activeDoc.selection.bounds;
		x1 = parseInt(boundsObj[0]); // 左上座標
		y1 = parseInt(boundsObj[1]);
		x2 = parseInt(boundsObj[2]); // 右下座標
		y2 = parseInt(boundsObj[3]);
		width = x2 - x1;
		height = y2 - y1;
	}catch(e){
	}

	if ( isLayerSet(activeLay) ){
		// レイヤーセットの場合、結合しないと真っ白になる
		copy_flag = true;
	}else{
		copy_flag = confirm("表示レイヤーを結合してコピーしますか？");
	}

	// レイヤーを選択してコピー
	var activeLayVisible = activeLay.visible;
	activeLay.visible = true; // 可視にしないとコピーに失敗する
	var selReg = [[x1,y1],[x1,y2],[x2,y2],[x2,y1]];
	activeDoc.selection.select(selReg);
	activeDoc.selection.copy(copy_flag);
	activeDoc.selection.deselect();
	activeLay.visible = activeLayVisible;

	// 新規ドキュメントを作成してペースト
	var newDoc = documents.add(width,height);
	newDoc.selection.selectAll();
	newDoc.paste();
	newDoc.layers[1].visible = false;  // 背景レイヤーを非表示

	// レイヤー名を変更
	var baseName = activeLay.name + "_x" + x1 + "y" + y1 +"_w" + (x2-x1) + "h" + (y2-y1);
	var newName = prompt("新規レイヤー名\r\n値をコピー( CTRL+C )できます", baseName);
	if(newName){
		newDoc.artLayers[0].name = newName;
	}
}

/// レイヤーセットかを判別
function isLayerSet(layer)
{
	var result = false;

	try{
		if(layer.typename == 'LayerSet'){
			result = true;
		}
	}catch(e){
	}

	return result;
}

////////////////////////////////////////////////////////////////////////////////
// run
////////////////////////////////////////////////////////////////////////////////
main();
